# django-sp [![PyPi license](https://img.shields.io/pypi/l/django-sp.svg)](https://pypi.python.org/pypi/django_sp)

## Pypi [![PyPi status](https://img.shields.io/pypi/status/django-sp.svg)](https://pypi.python.org/pypi/django_ps) [![PyPi version](https://img.shields.io/pypi/v/django-sp.svg)](https://pypi.python.org/pypi/django_sp) [![PyPi python version](https://img.shields.io/pypi/pyversions/django-sp.svg)](https://pypi.python.org/pypi/django_sp) [![PyPi downloads](https://img.shields.io/pypi/dm/django-sp.svg)](https://pypi.python.org/pypi/django_sp) [![PyPi downloads](https://img.shields.io/pypi/dw/django-sp.svg)](https://pypi.python.org/pypi/django_sp) [![PyPi downloads](https://img.shields.io/pypi/dd/django-sp.svg)](https://pypi.python.org/pypi/django_sp)

	$ pip install django-sp

## GitHub ![GitHub release](https://img.shields.io/github/tag/DLRSP/django-sp.svg) ![GitHub release](https://img.shields.io/github/release/DLRSP/django-sp.svg)

## Test [![codecov.io](https://codecov.io/github/DLRSP/django-sp/coverage.svg?branch=master)](https://codecov.io/github/DLRSP/django-sp?branch=master)

Report Issues with [***waffle.io***](https://waffle.io/DLRSP/django-sp/join)

## Run Example Project

	$ git clone https://github.com/DLRSP/example -b django-sp
	$ cd example
	$ python manage.py runserver

Now you browser the app @ http://127.0.0.1:8000
